=========
Changelog
=========

Version 0.1
===========

* Project skeleton created.
* `tox.ini` file created. Workflows should work now. 
	* Fix `tox.ini`. It should now have the build environment. 
* Comment out twine check, checking for correct rendering on PyPI